rse.logger package — The Research Software Encyclopedia 11 documentation

# rse.logger package

## Submodules

## rse.logger.message module

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

class rse.logger.message.RseMessage(MESSAGELEVEL=None)

  Bases: `object`

  abort(message)
  addColor(level, text)

    addColor to the prompt (usually prefix) if terminal supports, and specified to do so

  critical(message)
  custom(prefix, message='', color='\x1b[95m')
  debug(message)
  emit(level, message, prefix=None, color=None)

    emit is the main function to print the message optionally with a prefix

    Arguments:

      - level (int) : the level of the message

      - message (str) : the message to print

      - prefix (str) : a prefix for the message

  emitError(level)

    determine if a level should print to stderr, includes all levels but INFO and QUIET

  emitOutput(level)

    determine if a level should print to stdout only includes INFO

  error(message)
  exit(message, return_code=1)
  exit_info(message, return_code=0)
  failure(message)

    Given a message string, print as a failure in red.

    Parameters:

      - message: the message to print in red (indicating failure).

  get_logs(join_newline=True)

    ‘get_logs will return the complete history, joined by newline (default) or as is.

  info(message)
  isEnabledFor(messageLevel)

    check if a messageLevel is enabled to emit a level

  is_quiet()

    is_quiet returns true if the level is under 1

  log(message)
  newline()
  show_progress(iteration, total, length=40, min_level=0, prefix=None, carriage_return=True, suffix=None, symbol=None)

    create a terminal progress bar, default bar shows for verbose+

    Parameters

      - iteration (current iteration (Int))

      - total (total iterations (Int))

      - length (character length of bar (Int))

  success(message)

    Given a message string, print as a success in green.

    Parameters:

      - message: the message to print in green (indicating success).

  table(rows, col_width=2, labels=None)

    table will print a table of entries. If the rows is a dictionary, the keys are interpreted as column names. if not, a numbered list is used.

  useColor()

    useColor will determine if color should be added to a print. Will check if being run in a terminal, and if has support for asci

  verbose(message)
  verbose1(message)
  verbose2(message)
  verbose3(message)
  warning(message)
  write(stream, message)

    write will write a message to a stream, first checking the encoding

rse.logger.message.convert2boolean(arg)

  convert2boolean is used for environmental variables that must be returned as boolean

rse.logger.message.get_logging_level()

  get_logging_level will configure a logging to standard out based on selected level, which should be in an environment variable called MESSAGELEVEL. if MESSAGELEVEL is not set, the maximum level (5) is assumed (all messages).

rse.logger.message.get_user_color_preference()

## Module contents